Sphere

Struct Sphere 

pub struct Sphere<V: VectorSpace> {
    pub center: V,
    pub radius: V::Scalar,
}
A sphere collider defined by a center point and radius.

Fields

center: V

The center of the sphere.

radius: V::Scalar

The radius of the sphere.

Implementations

Source

impl<V: Copy + InnerSpace> Sphere<V>

pub fn new(center: V, radius: V::Scalar) -> Self

Creates a new sphere collider.

pub fn point(center: V) -> Self

Creates a sphere with zero radius, representing a single point.